# guided-interpolation
A Python repository for 2D and 3D horizons-guided interpolation

Here are some of the main features of guided-interpolation package
- Continuous properties horizon-guided interpolation through inverse weighted distance and ordinary kriging.
- Discrete properties horizon-guided interpolation through indicator kriging.

- Sequential gaussian and indicator simulations horizon-guided.

## Installation

You can install with `pip`:

    pip install guided_interpolation

## Documentation

Coming soon!

# Contributing

Please see [CONTRIBUTING.md](CONTRIBUTING.md).
